
# Slot: object


disease or phenotype

URI: [biolink:entity_to_disease_or_phenotypic_feature_association_mixin_object](https://w3id.org/biolink/vocab/entity_to_disease_or_phenotypic_feature_association_mixin_object)


## Domain and Range

[EntityToDiseaseOrPhenotypicFeatureAssociationMixin](EntityToDiseaseOrPhenotypicFeatureAssociationMixin.md) &#8594;  <sub>1..1</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [EntityToDiseaseOrPhenotypicFeatureAssociationMixin](EntityToDiseaseOrPhenotypicFeatureAssociationMixin.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Examples:** | | Example(value='MONDO:0017314', description='Ehlers-Danlos syndrome, vascular type') |
|  | | Example(value='MP:0013229', description='abnormal brain ventricle size') |

